/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2020 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#ifndef ASSOCIATED_QUALIFIERS_H
#define ASSOCIATED_QUALIFIERS_H

#include "ui_sequence_associated_qualifiers.h"
#include "ui_assembly_associated_qualifiers.h"
#include "ui_outfile_associated_qualifiers.h"
#include "ui_outseq_associated_qualifiers.h"
#include "ui_outfeat_associated_qualifiers.h"
#include "ui_features_associated_qualifiers.h"
#include "ui_graph_associated_qualifiers.h"
#include "ui_alignment_associated_qualifiers.h"
#include "ui_add_configuration_parameter.h"
#include "programWindowClass.h"

class SAQForm : public QDialog, private Ui::SequenceAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   SAQForm(kprogramWindow *parent = nullptr, const QString fseqNumber = "1");

private:
   kprogramWindow *parentProgramWindow;
   QString seqNumber;
   QStringList otherQualifiers;

private slots:
    void accept();
};

class AssemblyAQForm : public QDialog, private Ui::AssemblyAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   AssemblyAQForm(kprogramWindow *parent = nullptr, const QString fassemblyNumber = "1");

private:
   kprogramWindow *parentProgramWindow;
   QString assemblyNumber;
   QStringList otherQualifiers;

private slots:
    void accept();
};

class OAQForm : public QDialog, private Ui::OutfileAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   OAQForm(kprogramWindow *parent = nullptr, const QString num = "2");

private:
   kprogramWindow *parentProgramWindow;
   QString seqNumber;
   QStringList otherQualifiers;

private slots:
    void accept();
};

class OsAQForm : public QDialog, private Ui::OutseqAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   OsAQForm(kprogramWindow *parent = nullptr, const QString num = "2");

private:
   kprogramWindow *parentProgramWindow;
   QString seqNumber;
   QStringList otherQualifiers;

private slots:
    void accept();
};

class OfAQForm : public QDialog, private Ui::OutfeatAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   OfAQForm(kprogramWindow *parent = nullptr, const QString num = "3");

private:
   kprogramWindow *parentProgramWindow;
   QString seqNumber;
   QStringList otherQualifiers;

private slots:
    void accept();
};

class FAQForm : public QDialog, private Ui::FeaturesAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   FAQForm(kprogramWindow *parent = nullptr, const QString num = "1");

private:
   kprogramWindow *parentProgramWindow;
   QString seqNumber;
   QStringList otherQualifiers;

private slots:
    void accept();
};

class GAQForm : public QDialog, private Ui::GraphAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   GAQForm(kprogramWindow *parent = nullptr, const QString num = "");
   QString seqNumber;
   QStringList otherQualifiers;

private:
   kprogramWindow *parentProgramWindow;

private slots:
    void accept();
};

class AAQForm : public QDialog, private Ui::AlignmentAssociatedQualifiersDialog
{
   Q_OBJECT

public:
   AAQForm(kprogramWindow *parent = nullptr, const QString num = "3");
   QString seqNumber;
   QStringList otherQualifiers;

private:
   kprogramWindow *parentProgramWindow;

private slots:
    void accept();
};

class ACPForm : public QDialog, private Ui::AddConfigurationParameterDialog
{
   Q_OBJECT

public:
   ACPForm(kprogramWindow *parent = nullptr);

private:
   kprogramWindow *parentProgramWindow;

private slots:
    void accept();
};

#endif
