/***************************************************************************
 *                                                                         *
 *   kemboss - Graphical user interface for EMBOSS                         *
 *                                                                         *
 *   Copyright (C) 2007-2013 Tobias Schwarz (mail@tobias-schwarz.net)      *
 *                                                                         *
 *   Based on the EMBOSS.kaptn scripts by Thomas Siegmund                  *
 *                                                                         *
 *   This program is free software; you can redistribute and/or modify     *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version, and provided that the above       *
 *   copyright and permission notice is included with all distributed      *
 *   copies of this or derived software.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 **************************************************************************/

#include "phylipProgramWindows.h"

void kfbootstrap::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-test="+TestComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-justweights="+OutputFormatComboBox3->currentText().left(1));
   if (runEmbossApp->embossApp() == "fseqboot" || runEmbossApp->embossApp() == "fseqbootall") {
      runEmbossApp->programConfiguration.append("-seqtype="+OutputFormatComboBox2->currentText().left(1));
   }
   if (runEmbossApp->embossApp() == "fseqboot" || runEmbossApp->embossApp() == "fseqbootall" || runEmbossApp->embossApp() == "frestboot") {
      runEmbossApp->programConfiguration.append("-rewriteformat="+OutputFormatComboBox->currentText().left(1));
   }
   if (runEmbossApp->embossApp() == "fseqbootall") {
      runEmbossApp->programConfiguration.append("-datatype="+DataTypeComboBox->currentText().left(1));
      runEmbossApp->programConfiguration.append("-morphseqtype="+OutputFormatComboBox4->currentText().left(1));
   }
   runEmbossApp->addEmbossInputFile(InputCategoriesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(MixturesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(AncestorsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(FactorsFileLineEdit->text());
}

void kfbootstrap::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool prog = false;
   if (text == "fseqboot") {
      InputFileLineEdit->setToolTip("sequence");
   } else if (text == "ffreqboot" || text == "frestboot") {
      InputFileLineEdit->setToolTip("infile");
   } else if (text == "fseqbootall") {
      prog = true;
      InputFileLineEdit->setToolTip("infilesequences");
   }
   MixturesFileLabel->setEnabled(prog);
   MixturesFileLineEdit->setEnabled(prog);
   MixturesFilePushButton->setEnabled(prog);
   AncestorsFileLabel->setEnabled(prog);
   AncestorsFileLineEdit->setEnabled(prog);
   AncestorsFilePushButton->setEnabled(prog);
   FactorsFileLabel->setEnabled(prog);
   FactorsFileLineEdit->setEnabled(prog);
   FactorsFilePushButton->setEnabled(prog);
   DataTypeLabel->setEnabled(prog);
   DataTypeComboBox->setEnabled(prog);
   OutputFormatLabel4->setEnabled(prog);
   OutputFormatComboBox4->setEnabled(prog);
   AllAllelesPresentAtEachLocusCheckBox->setEnabled(prog);

   if (text == "fseqbootall" || text == "frestboot") {
      prog = true;
   } else {
      prog = false;
   }
   NumberOfEnzymesInInputfileCheckBox->setEnabled(prog);

   if (text == "ffreqboot" || text == "frestboot") {
      prog = false;
   } else {
      prog = true;
   }
   SequenceAssociatedQualifiersPushButton->setEnabled(prog);
   InputCategoriesFileLabel->setEnabled(prog);
   InputCategoriesFileLineEdit->setEnabled(prog);
   InputCategoriesFilePushButton->setEnabled(prog);
   OutputFormatLabel2->setEnabled(prog);
   OutputFormatComboBox2->setEnabled(prog);

   if (text == "ffreqboot") {
      prog = false;
   } else {
      prog = true;
   }
   OutputFormatLabel->setEnabled(prog);
   OutputFormatComboBox->setEnabled(prog);

   runEmbossApp->setEmbossApp(text);
}

void kfclique::beforeRunningProgram()
{
   runEmbossApp->addEmbossInputFile(AncestralStatesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(MultistateFactorsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "fclique");
}

void kfcontml::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-datatype="+InfileDataTypeComboBox->currentText().left(1));
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "fcontml");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kfcontrast::beforeRunningProgram()
{
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kfconsense::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-method="+MethodComboBox->currentText().section(" ", 0, 0));
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "fconsense");
}

void kfdiscboot::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-test="+TestComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-morphseqtype="+OutputFormatComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-justweights="+OutputFormatComboBox3->currentText().left(1));
   completeOutputFilename(AncestorOutputFileLineEdit, "ancestor");
   completeOutputFilename(MixOutputFileLineEdit, "mixture");
   completeOutputFilename(FactorOutputFileLineEdit, "factor");
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(MixturesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(AncestorsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(FactorsFileLineEdit->text());
}

void kfdnacomp::beforeRunningProgram()
{
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "fdnacomp");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossInputFile(InputFileLineEdit3->text());
}

void kfdnadist::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-method="+MethodComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-gamma="+GammaDistributionComboBox->currentText().left(1));
   if (FixedBaseFrequenciesGroupBox->isChecked()) {
      runEmbossApp->programConfiguration.append("-nofreqsfrom");
      QString anum;
      QString cnum;
      QString gnum;
      QString tnum;
      anum.setNum(ADoubleSpinBox->value());
      cnum.setNum(CDoubleSpinBox->value());
      gnum.setNum(GDoubleSpinBox->value());
      tnum.setNum(TUDoubleSpinBox->value());
      runEmbossApp->programConfiguration.append("-basefreq="+anum+" "+cnum+" "+gnum+" "+tnum);
   }
   runEmbossApp->addEmbossInputFile(SubstitutionRateCategoriesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
}

void kfdnainvar::beforeRunningProgram()
{
    runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kfdnaml::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-gammatype="+GammaDistributionComboBox->currentText().left(1));
   if (FixedBaseFrequenciesGroupBox->isEnabled() && FixedBaseFrequenciesGroupBox->isChecked()) {
      runEmbossApp->programConfiguration.append("-nofreqsfrom");
      QString anum;
      QString cnum;
      QString gnum;
      QString tnum;
      anum.setNum(ADoubleSpinBox->value());
      cnum.setNum(CDoubleSpinBox->value());
      gnum.setNum(GDoubleSpinBox->value());
      tnum.setNum(TUDoubleSpinBox->value());
      runEmbossApp->programConfiguration.append("-basefreq="+anum+" "+cnum+" "+gnum+" "+tnum);
   }
   if (runEmbossApp->embossApp() == "fproml" || runEmbossApp->embossApp() == "fpromlk") runEmbossApp->programConfiguration.append("-model="+ModelComboBox->currentText().left(1));
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "fdnaml");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossInputFile(SubstitutionRateCategoriesFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
}

void kfdnaml::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   if (text == "fdnaml" || text == "fproml") {
      SpeedierAnalysisCheckBox->setEnabled(true);
   } else {
      SpeedierAnalysisCheckBox->setEnabled(false);
   }

   bool prog = true;
   if (text == "fdnamlk") {
      prog = false;
   }
   OutgroupNumberLabel->setEnabled(prog);
   OutgroupNumberSpinBox->setEnabled(prog);

   if (text == "fproml" || text == "fpromlk") {
      prog = true;
   } else {
      prog = false;
   }
   ModelLabel->setEnabled(prog);
   ModelComboBox->setEnabled(prog);
   FixedBaseFrequenciesGroupBox->setEnabled(!prog);
   TransitionTransversionRatioLabel->setEnabled(!prog);
   TransitionTransversionRatioDoubleSpinBox->setEnabled(!prog);

   runEmbossApp->setEmbossApp(text);
}

void kfdollop::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-method="+MethodComboBox->currentText().left(1));
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "fdollop");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(MixtureFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(AncestralStatesFileLineEdit->text());
}

void kfdollop::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool prog = false;
   QStringList list;
   if (text == "fdollop") {
      list <<"d (Dollo)" << "p (Polymorphism)";
   } else {
      prog = true;
      list << "w (Wagner)" << "c (Camin-Sokal)" << "m (Mixed)";
   }
   MixtureStatesFileLabel->setEnabled(prog);
   MixtureFileLineEdit->setEnabled(prog);
   MixtureFilePushButton->setEnabled(prog);
   OutgroupNumberLabel->setEnabled(prog);
   OutgroupNumberSpinBox->setEnabled(prog);
   MethodComboBox->clear();
   MethodComboBox->addItems(list);
   runEmbossApp->setEmbossApp(text);
}

void kfdraw::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool prog = false;
   if (text == "fdrawgram") prog = true;

   TreeGrowsHorizontallyCheckBox->setEnabled(prog);
   TreeStyleOutputLabel->setEnabled(prog);
   TreeStyleOutputComboBox->setEnabled(prog);
   IterateLabel->setEnabled(!prog);
   IterateComboBox->setEnabled(!prog);
   LabelDirectionLabel->setEnabled(!prog);
   LabelDirectionComboBox->setEnabled(!prog);
   TreeangleLabel->setEnabled(!prog);
   TreeangleDoubleSpinBox->setEnabled(!prog);
   ArcAngleLabel->setEnabled(!prog);
   ArcAngleDoubleSpinBox->setEnabled(!prog);
   StemlengthLabel->setEnabled(prog);
   StemlengthDoubleSpinBox->setEnabled(prog);
   NodespaceLabel->setEnabled(prog);
   NodespaceDoubleSpinBox->setEnabled(prog);
   NodepositionLabel->setEnabled(prog);
   NodepositionComboBox->setEnabled(prog);

   runEmbossApp->setEmbossApp(text);
}

void kfdraw::beforeRunningProgram()
{
   if (runEmbossApp->embossApp() == "fdrawgram") {
      runEmbossApp->programConfiguration.append("-style="+TreeStyleOutputComboBox->currentText().left(1));
      runEmbossApp->programConfiguration.append("-nodeposition="+NodepositionComboBox->currentText().left(1));
   } else {
      runEmbossApp->programConfiguration.append("-iterate="+IterateComboBox->currentText().left(1));
      runEmbossApp->programConfiguration.append("-labeldirection="+LabelDirectionComboBox->currentText().left(1));
   }
   runEmbossApp->programConfiguration.append("-plotter="+PlotterComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-previewer="+PreviewerComboBox->currentText().left(1));
}

void kffactor::beforeRunningProgram()
{
   completeOutputFilename(AncestorOutputFileLineEdit, "ancestor");
   completeOutputFilename(FactorOutputFileLineEdit, "factor");
}

void kfgendist::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-method="+MethodComboBox->currentText().left(1));
}

void kfmatrix::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-matrixtype="+MatrixTypeComboBox->currentText().left(1));
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "tree");
   if (runEmbossApp->embossApp() == "fneighbor") runEmbossApp->programConfiguration.append("-treetype="+MethodComboBox->currentText().left(1));
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kfmatrix::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool prog = false;
   if (text == "ffitch") {
      prog = true;
   }
   UseUserTreeLengthCheckBox->setEnabled(prog);
   GlobalRearrangementsCheckBox->setEnabled(prog);

   if (text == "fkitsch") {
      prog = false;
   } else {
      prog = true;
   }
   OutgroupNumberLabel->setEnabled(prog);
   OutgroupNumberSpinBox->setEnabled(prog);

   if (text == "fneighbor") {
      prog = false;
   } else {
      prog = true;
   }
   TreeFileLabel->setEnabled(prog);
   InputFileLineEdit2->setEnabled(prog);
   OpenInputFilePushButton2->setEnabled(prog);
   SaveInputFileAsPushButton2->setEnabled(prog);
   MethodLabel->setEnabled(!prog);
   MethodComboBox->setEnabled(!prog);
   MinimumEvolutionCheckBox->setEnabled(prog);
   RandomizeInputOrderCheckBox->setEnabled(!prog);
   TimesToRandomizeLabel->setEnabled(prog);
   TimesToRandomizeSpinBox->setEnabled(prog);
   PowerLabel->setEnabled(prog);
   PowerDoubleSpinBox->setEnabled(prog);
   NegativeBranchLengthsAllowedCheckBox->setEnabled(prog);
   runEmbossApp->setEmbossApp(text);
}

void kfpars::beforeRunningProgram()
{
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "tree");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
   if (runEmbossApp->embossApp() == "fpars") runEmbossApp->programConfiguration.append("-method="+MethodComboBox->currentText().left(1));
   if (runEmbossApp->embossApp() == "fprotpars") runEmbossApp->programConfiguration.append("-whichcode="+PhylipGeneticCodeComboBox->currentText().left(1));
}

void kfpars::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool prog = false;
   if (text == "fpars") {
      prog = true;
      InputFileLineEdit->setToolTip("infile");
   } else {
      InputFileLineEdit->setToolTip("sequence");
   }
   SequenceAssociatedQualifiersPushButton->setEnabled(!prog);
   MethodLabel->setEnabled(prog);
   MethodComboBox->setEnabled(prog);

   if (text == "fprotpars") {
      prog = false;
   } else {
      prog = true;
   }
      MaxtreesLabel->setEnabled(prog);
      MaxtreesSpinBox->setEnabled(prog);
      ThoroughSearchCheckBox->setEnabled(prog);
      RearrangeCheckBox->setEnabled(prog);
      GeneticCodeLabel->setEnabled(!prog);
      PhylipGeneticCodeComboBox->setEnabled(!prog);

   if (text == "fdnapars") {
      TransversionCheckBox->setEnabled(true);
   } else {
      TransversionCheckBox->setEnabled(false);
   }

   runEmbossApp->setEmbossApp(text);
}

void kfpenny::beforeRunningProgram()
{
   if (runEmbossApp->embossApp() == "fpenny" || runEmbossApp->embossApp() == "fdolpenny") runEmbossApp->programConfiguration.append("-method="+MethodComboBox->currentText().section(" ", 0, 0));
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(MixtureFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(AncestralStatesFileLineEdit->text());
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "fpenny");
}

void kfpenny::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   bool prog = false;
   if (text == "fdnapenny") {
      InputFileLineEdit->setToolTip("sequence");
   } else {
      InputFileLineEdit->setToolTip("infile");
      prog = true;
   }
   SequenceAssociatedQualifiersPushButton->setEnabled(!prog);
   AncestralStatesFileLabel->setEnabled(prog);
   AncestralStatesFileLineEdit->setEnabled(prog);
   AncestralStatesFilePushButton->setEnabled(prog);
   MethodLabel->setEnabled(prog);
   MethodComboBox->setEnabled(prog);

   QStringList list;
   if (text == "fpenny") {
      prog = true;
      BranchAndBoundIsSimpleCheckBox->setToolTip("simple");
      list << "Wag (Wagner)" << "Cam (Camin-Sokal)" << "Mix (Mixed)";
   } else {
      prog = false;
      BranchAndBoundIsSimpleCheckBox->setToolTip("[no]simple");
      list <<"d (Dollo)" << "p (Polymorphism)";
   }
   MixtureStatesFileLabel->setEnabled(prog);
   MixtureFileLineEdit->setEnabled(prog);
   MixtureFilePushButton->setEnabled(prog);
   UseThresholdCheckBox->setEnabled(!prog);
   MethodComboBox->clear();
   MethodComboBox->addItems(list);

   if (text == "fdolpenny") {
      prog = false;
   } else {
      prog = true;
   }
   OutgroupNumberLabel->setEnabled(prog);
   OutgroupNumberSpinBox->setEnabled(prog);

   runEmbossApp->setEmbossApp(text);
}

void kfprotdist::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-method="+MethodComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-gamma="+GammaDistributionComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-whichcode="+PhylipGeneticCodeComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-aacateg="+CategoryComboBox->currentText().left(1));
   QString anum;
   QString cnum;
   QString gnum;
   QString tnum;
   anum.setNum(ADoubleSpinBox->value());
   cnum.setNum(CDoubleSpinBox->value());
   gnum.setNum(GDoubleSpinBox->value());
   tnum.setNum(TUDoubleSpinBox->value());
   runEmbossApp->programConfiguration.append("-basefreq="+anum+" "+cnum+" "+gnum+" "+tnum);
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
   runEmbossApp->addEmbossInputFile(SubstitutionRateCategoriesFileLineEdit->text());
}

void kfrestml::beforeRunningProgram()
{
   if (CreateTreeFileGroupBox->isChecked()) completeOutputFilename(OutputFileLineEdit2, "frestml");
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
   runEmbossApp->addEmbossInputFile(WeightsFileLineEdit->text());
}

void kftreedist::beforeRunningProgram()
{
   runEmbossApp->programConfiguration.append("-dtype="+DistanceTypeComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-pairing="+TreePairingMethodComboBox->currentText().left(1));
   runEmbossApp->programConfiguration.append("-style="+DistancesOutputOptionComboBox->currentText().left(1));
   runEmbossApp->addEmbossInputFile(InputFileLineEdit2->text());
}

void kftreedist::on_ProgramComboBox_currentIndexChanged(const QString &text)
{
   TreePairingMethodComboBox->clear();
   bool prog = false;
   if (text == "ftreedist") {
      TreePairingMethodComboBox->addItem("a (Distance between adjacent pairs in tree file)");
      TreePairingMethodComboBox->addItem("p (Distances between all possible pairs in tree file)");
   } else {
      prog = true;
      TreePairingMethodComboBox->addItem("l (Distances between all possible pairs in each tree file)");
      TreePairingMethodComboBox->addItem("c (Distances between corresponding pairs each tree file)");
   }
   SecondTreeFileLabel->setEnabled(prog);
   InputFileLineEdit2->setEnabled(prog);
   OpenInputFilePushButton2->setEnabled(prog);
   SaveInputFileAsPushButton2->setEnabled(prog);
   runEmbossApp->setEmbossApp(text);
}
